import os
import sys
import subprocess
import shlex

def run_tinygo():
    dir_name = os.path.dirname(os.path.realpath(__file__))
    dir_name = os.path.join(dir_name, "tinygo")
    tinygo = os.path.join(dir_name, 'bin/tinygo')
    if len(sys.argv) <= 1:
        return subprocess.call(tinygo)
    elif sys.argv[1] == "build":
        cmd = [tinygo]
        args = 'build -x -gc=leaking -target eosio -wasm-abi=generic -scheduler=none -opt z -tags=math_big_pure_go'
        args = shlex.split(args)
        cmd.extend(args)
        cmd.extend(sys.argv[2:])
        return subprocess.call(cmd)
    else:
        cmd = sys.argv[:]
        cmd[0] = tinygo
        return subprocess.call(cmd)



import os
import setuptools
# from skbuild import setup
from distutils.core import setup

from distutils.sysconfig import get_python_lib
import glob

release_files = []
for root, dirs, files in os.walk("pysrc/tinygo"):
    for f in files:
        release_files.append(os.path.join(root.replace('pysrc/', ''), f))    

print(release_files)

setup(
    name="gscdk",
    version="0.1.6",
    description="Go Smart Contract Development Kit",
    author='The UUOSIO Team',
    license="BSD-3-Clause",
    packages=['gscdk'],
    package_dir={'gscdk': 'pysrc'},
    package_data={
#        "": ["*"],
        'gscdk': release_files,
    },
    setup_requires=['wheel']
    # scripts=['compiler/build/release/tinygo/bin/eosio-go'],
    # install_requires=[
    # ],
    # include_package_data=True
)
